<?php
/**
 * Aphollo functions and definitions
 *
 * @package Aphollo
 */
if ( ! isset( $content_width ) ) {$content_width = 640; /* pixels */}
if ( ! function_exists( 'aphollo_setup' ) ) :
function aphollo_setup() {
	/* Make theme available for translation. */
	load_theme_textdomain( 'aphollo', get_template_directory() . '/languages' );
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	/* Enable support for Post Thumbnails on posts and pages. */
	add_theme_support( 'post-thumbnails' );
	// add_editor_style();
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'aphollo' ),
	));
	/* Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	)); */
	/* Enable support for Post Formats.
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	)); */
	// Enable support for title-tag.
	add_theme_support( 'title-tag' );
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'aphollo_custom_background_args', array(
		'default-color' => '',
		'default-image' => '',
	)));
}
endif; // aphollo_setup
add_action( 'after_setup_theme', 'aphollo_setup' );

/* Register widget area. */
function aphollo_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'aphollo' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	));
	// Footer A
	register_sidebar( array(
		'name'          => __( 'Footer A', 'aphollo' ),
		'id'            => 'sidebar-6',
		'before_widget' => '<aside id="%1$s" class="widget_foot %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	));
	// Footer B
	register_sidebar( array(
		'name'          => __( 'Footer B', 'aphollo' ),
		'id'            => 'sidebar-7',
		'before_widget' => '<aside id="%1$s" class="widget_foot %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	));
	// Footer C
	register_sidebar( array(
		'name'          => __( 'Footer C', 'aphollo' ),
		'id'            => 'sidebar-8',
		'before_widget' => '<aside id="%1$s" class="widget_foot %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	));
	// Footer C
	register_sidebar( array(
		'name'          => __( 'Footer D', 'aphollo' ),
		'id'            => 'sidebar-9',
		'before_widget' => '<aside id="%1$s" class="widget_foot %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	));
}
add_action( 'widgets_init', 'aphollo_widgets_init' );

/* Enqueue scripts and styles. */
function aphollo_scripts() {
  wp_enqueue_style( 'aphollo-style', get_stylesheet_uri() );
  wp_enqueue_style( 'aphollo-fonts', '//fonts.googleapis.com/css?family=Poiret+One', array(), null );
  wp_enqueue_style( 'aphollo-cs', get_template_directory_uri() . '/css/aphollo-assets.css', array(), null );
  wp_enqueue_script('modernizr-js', get_template_directory_uri().'/js/modernizr.min.js', array(), '20133029', false );
  wp_enqueue_script('aphollo-js', get_template_directory_uri().'/js/aphollo.js', array(), '20130102', true );
  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
	  wp_enqueue_script( 'comment-reply' );
  }
}
add_action( 'wp_enqueue_scripts', 'aphollo_scripts' );

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';
/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';
/* Custom functions that act independently of the theme templates. */
require get_template_directory() . '/inc/extras.php';
/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';
/* Load Jetpack compatibility file. */
require get_template_directory() . '/inc/jetpack.php';

// Help Menú y submenú
include_once dirname( __FILE__ ) . '/help/help.php';
add_action('admin_menu', 'help_menu');
function help_menu() {
	add_theme_page('Help Aphollo', __( 'Help Aphollo','aphollo'), 'edit_theme_options', 'manage_options', 'help_function');
}

/* Adds IE specific scripts */
function aphollo_ie_scripts() {
?>
<!--[if lt IE 9]>
 <script src="<?php echo get_template_directory_uri(); ?>/js/respond.js" type="text/javascript"></script>
<![endif]-->
<?php
}
add_action( 'wp_head', 'aphollo_ie_scripts', 11 );
// Add Favicon
function aphollo_favicon() {
?>
<link rel="shortcut icon" href="<?php if ( of_get_option('aphollo_favicon') !='' ) { ?><?php echo of_get_option('aphollo_favicon'); ?><?php } else { ?><?php echo get_template_directory_uri(); ?>/images/wp-favicon.png<?php } ?>">
<?php
}
add_action( 'wp_head', 'aphollo_favicon' );

/* Loads the Options Panel */
define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once dirname( __FILE__ ) . '/inc/options-framework.php';
require_once get_template_directory() . '/inc/options.php';
add_action( 'optionsframework_custom_scripts', 'optionsframework_custom_scripts' );
function optionsframework_custom_scripts() { ?>
<script type="text/javascript">
jQuery(document).ready(function() {
  jQuery('#example_showhidden').click(function() {
	  jQuery('#section-example_text_hidden').fadeToggle(400);
  });
  if (jQuery('#example_showhidden:checked').val() !== undefined) {
	  jQuery('#section-example_text_hidden').show();
  }
});
</script>
<?php
}

/* Donativos */
// Aphollo opciones con sidebar
add_action( 'optionsframework_after','aphollo_options_display_sidebar' );

function aphollo_options_display_sidebar() { ?>
<div id="optionsframework-sidebar">
  <div class="metabox-holder">
    <div class="postbox">
      <h3><?php esc_attr_e( 'Do you like the theme Aphollo?', 'aphollo' ); ?><br>
      <span style="color:#090"><?php esc_attr_e( 'Buy me a burger!', 'aphollo' ); ?></span></h3>
      <div class="inside"> 
      <p><?php esc_attr_e( 'Help us keep working for you on the update of this issue and the improvement. You can make a donation to your choice or collaboration with the developer :-)', 'aphollo' ); ?></p>
      
      <div align="center" style="padding:5px; background-color:#fafafa;border: 1px solid #CCC;margin-bottom: 10px;">
      <strong><?php esc_attr_e( 'Collaborate', 'aphollo' ); ?></strong>
      <form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_blank">
      <input type="hidden" name="cmd" value="_s-xclick">
      <input type="hidden" name="hosted_button_id" value="RBRN8PNKNA27L">
      
      <input type="hidden" name="on0" value="Collaboration"><br>
      <select name="os0">
          <option value="for a Burger"><?php esc_attr_e( 'for a Burger &#8364;2,00 EUR', 'aphollo' ); ?></option>
          <option value="for Beer"><?php esc_attr_e( 'for Beer &#8364;1,45 EUR', 'aphollo' ); ?></option>
          <option value="for Coca-Cola"><?php esc_attr_e( 'for Coca-Cola &#8364;1,20 EUR', 'aphollo' ); ?></option>
          <option value="for Coffee"><?php esc_attr_e( 'for Coffee &#8364;0,80 EUR', 'aphollo' ); ?></option>
          <option value="All"><?php esc_attr_e( 'All &#8364;5,45 EUR', 'aphollo' ); ?></option>
      </select><br>
      <input type="hidden" name="on1" value="Opinion"><?php esc_attr_e( 'Opinion', 'aphollo' ); ?><br>
      <select name="os1">
          <option value="Very good"><?php esc_attr_e( 'Very good', 'aphollo' ); ?></option>
          <option value="Good"><?php esc_attr_e( 'Good', 'aphollo' ); ?></option>
          <option value="Not bad"><?php esc_attr_e( 'Not bad', 'aphollo' ); ?></option>
          <option value="Keep working"><?php esc_attr_e( 'Keep working', 'aphollo' ); ?></option>
      </select><br>
      <input type="hidden" name="currency_code" value="EUR">
      <input type="image" src="https://www.paypalobjects.com/es_ES/ES/i/btn/btn_paynow_LG.gif" border="0" name="submit" alt="PayPal. La forma rapida y segura de pagar en Internet.">
      <img alt="" border="0" src="https://www.paypalobjects.com/es_ES/i/scr/pixel.gif" width="1" height="1">
      </form>
      </div>
      
      <div align="center" style="padding:5px; background-color:#fafafa;border: 1px solid #CCC;margin-bottom: 10px;">
      <strong><?php esc_attr_e( 'Voluntary donation', 'aphollo' ); ?></strong>
      <form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_blank">
      
      <input type="hidden" name="cmd" value="_s-xclick">
      <input type="hidden" name="hosted_button_id" value="LD46KHJWG67NL">
      <input type="image" src="https://www.paypalobjects.com/es_ES/ES/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal. La forma rapida y segura de pagar en Internet.">
      <img alt="" border="0" src="https://www.paypalobjects.com/es_ES/i/scr/pixel.gif" width="1" height="1">
      </form>
      </div>
      <p><strong><a href="<?php echo esc_url( __( 'http://www.ibermega.com/themes/aphollo/', 'aphollo' ) ); ?>" target="_blank"><?php _e('Aphollo Documentation','aphollo'); ?></a></strong></p>
      </div>
    </div>
  </div>
</div>
<?php }